#ifndef __CMDREPLYSIZE_H__
#define __CMDREPLYSIZE_H__

#include "CmdReply.h"
#include "CmdClientTypes.h"

namespace Aspera {

namespace Command {

    class Buffer;

    /*! \brief
    *  Class to parse and hold the reply of a as_du command objects
    */
    class CmdReplySize : public CmdReply
    {

    private:
        const static char Size            = 0x01;
        const static char FileCount       = 0x02;
        const static char DirCount        = 0x03;
        const static char FailedFileCount = 0x04;
        const static char FailedDirCount  = 0x05;

    private:
        int64_t size;
        int32_t fcount;
        int32_t dcount;
        int32_t failedfcount;
        int32_t faileddcount;

    public:
        CmdReplySize(CommandClientImpl *cc);
        ~CmdReplySize();
        int     processMsgBuffer(Buffer *rawBuffer);
        void    printReply();
        /*! \brief
        *  Returns the size in no. of bytes
        */
        int64_t getSize();

        /*! \brief
        *  Returns the no of files
        */
        int32_t getFileCount();

        /*! \brief
        *  Returns the no of directories
        */
        int32_t getDirCount();

        /*! \brief
        *  Returns the no of failed files
        */
        int32_t getFailedFileCount();

        /*! \brief
        *  Returns the no of failed directories
        */
        int32_t getFailedDirCount();
    };
}
}
#endif
